package net.sf.itcb.addons.cachemanager;
import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

import net.sf.ehcache.CacheManager;
import net.sf.itcb.common.business.core.ItcbApplicationContextHolder;

/**
 * This class is a filter you can put in your webapps to reload all the cache in the cacheManager.
 * Developers can also reload a specific cache giving cache name as "?name" request parameter
 * <pre>
 * {@code
 *  <filter>
 *		<display-name>ehCachefilter</display-name>
 *		<filter-name>ehCachefilter</filter-name>
 *		<filter-class>net.sf.itcb.addons.cachemanager.ItcbEhCacheFilter</filter-class>
 *	</filter>
 *	
 *	<filter-mapping>
 *		<filter-name>ehCachefilter</filter-name>
 *		<url-pattern>/reloadEhcache/*</url-pattern>
 *		<dispatcher>REQUEST</dispatcher>
 *	</filter-mapping>
 * }</pre>
 * 
 * @author Pierre Le Roux
 * @since 0.1.1
 *
 */
public class ItcbEhCacheFilter implements Filter {

	@Override
	public void init(FilterConfig filterConfig) throws ServletException {
		
	}

	@Override
	public void doFilter(ServletRequest request, ServletResponse response,
			FilterChain chain) throws IOException, ServletException {
		CacheManager cacheManager = ItcbApplicationContextHolder.getContext().getBean("global-cacheManager", net.sf.ehcache.CacheManager.class);
	    
		if(request.getParameter("name") != null ) {
			cacheManager.removeCache(request.getParameter("name"));
		}
		cacheManager.clearAll();
		
		response.getOutputStream().println("OK Cache had been cleared for this webapp");
	}

	@Override
	public void destroy() {
		
	}

}
